#
# spec file for package libnvme
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1

Name:           libnvme
Version:        1.4
Release:        3.1
Summary:        Linux-native nvme device management library
License:        LGPL-2.1-or-later
URL:            https://github.com/linux-nvme/libnvme/
Source0:        libnvme-%{version}.tar.gz
BuildRequires:  dbus-1-devel
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  keyutils-devel
BuildRequires:  libjson-c-devel
BuildRequires:  libuuid-devel
BuildRequires:  make
BuildRequires:  meson >= 0.50.0
BuildRequires:  openssl-devel
BuildRequires:  python3-devel
BuildRequires:  swig

%description
Provides library functions for accessing and managing NVMe devices on a Linux
system.

%package -n %{name}%{sover}
Summary:        Linux-native nvme device management library

%description -n %{name}%{sover}
Provides library functions for accessing and managing NVMe devices on a Linux
system.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{sover} = %{version}
Requires:       %{name}-mi%{sover} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        mi%{sover}
Summary:        NVMe Managament Interface library for %{name}

%description    mi%{sover}
Provides library functions for managing NVMe devices via the NVMe
Managament Interface.

%package -n     python3-libnvme
Summary:        Python binding for %{name}

%description -n python3-libnvme
Provides library functions for accessing and managing NVMe devices on a Linux
system.

Python binding part.

%prep
%autosetup -p1

%build
export KBUILD_BUILD_TIMESTAMP=@${SOURCE_DATE_EPOCH:-$(date +%s)}
%meson -Ddocs=man %{?_with_docs_build:-Ddocs-build=true}
%meson_build

%install
%meson_install

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%post -n %{name}-mi%{sover} -p /sbin/ldconfig
%postun -n %{name}-mi%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%doc README.md
%{_libdir}/%{name}.so.%{sover}*

%files devel
%doc README.md
%{_includedir}/*
%{_libdir}/%{name}*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-mi.pc
%{_mandir}/*/*.gz

%files -n %{name}-mi%{sover}
%license COPYING
%doc README.md
%{_libdir}/%{name}-mi.so.%{sover}*

%files -n python3-libnvme
%dir %{python3_sitearch}/libnvme
%{python3_sitearch}/libnvme/*.so
%{python3_sitearch}/libnvme/__init__.py
%{python3_sitearch}/libnvme/nvme.py
%pycache_only %{python3_sitearch}/libnvme/__pycache__

%changelog
* Thu Jul 27 2023 Ana Guerrero <ana.guerrero@suse.com>
- Fix build with meson 1.2.0
* Fri Mar 31 2023 Daniel Wagnrer <daniel.wagner@suse.com>
- Update to version 1.4:
  * fabrics: Filter out invalid UUIDs from DMI
  * fabrics: Add define for DMI sysinfo
  * Print out correct TREQ strings for discovery
  * tree: fix generic device open failure
  * fabrics: add configuration option 'tls_key'
  * fabrics: add configuration option 'keyring'
  * linux: add key helper functions
  * nvme: add 'nvme_insert_tls_key()' function
  * linux: add nvme_lookup_keyring()
  * python: Change python option from combo to feature
  * types: add opcode field to error log page (TP4113)
  * python: Add setter property for controller DHCHAP Key
  * python: Remove redundant host.set_key() method
  * build, meson: Print option summary
  * Python: Add support for setting/getting Host DHCHAP key
  * Python: Add hostnqn_from_file() and hostid_from_file()
  * types: Update position of elbatm in struct nvme_copy_range{_f1}
  * doc: fix kernel-doc-check warning
  * python, meson: Assert that deps are present for -Dpython=true
  * python: Reformat SWIG input file
  * python test: Check there is no SIGSEGV during garbage collection
  * python: Return PyObject* from __str__() instead of a static char[]
  * python: Fix segmentation fault during garbage collection
  * build: Enable test in muon minimal build
  * build: Streamline workflows with nvme-cli
  * mi: Add nvme_mi_admin_get_log_page
  * ioctl: Set file descriptor in nvme_get_log_page()
  * fix endians
  * fabrics: Do not ignore one char whitespace when string sanitizing
* Mon Jan 30 2023 Daniel Wagner <daniel.wagner@suse.com>
- Update to version 1.3:
  * Support added for Flexible Data Placement (TP4146)
  * Fabrics: added support for Persistent Discovery Controllers.
  * libnvme-mi added a quirk framework to workaround special behavior of
  certain devices
  * The python binding behaves more friendly in a threading environment
  by release the GIL on blocking calls.
  * Replaced  3the libsystemd dependency with libdbus
  * A lot of small fixes everywhere (leaks, wrong ordering of arguments, ...)
- Update spec file
  * Project depends on meson >= 0.50.0
* Wed Nov  2 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to version 1.2:
  * Add more details for return code of MI admin cmds
  * Parse dhchap_host_key on controller level
  * Update json config schema for missing dhchap host key
  * fabrics: Add new TP8010 definitions
  * fabrics: Add nvmf_get_discovery_wargs()
  * fabrics: Duplicate strings when merging configs
  * fabrics: Filter out empty strings in add_argument()
  * fabrics: Use fallthrough statement
  * ioctl: Set log page offset for nvme_get_log_telemetry_host
  * json-schema: add dhchap_key details to host section
  * json: Enforce correctly formatted JSON config files
  * json: Verify JSON config file starts with an array
  * mi: Add Get Log Page helpers
  * mi: Add Identify function for secondary controller list
  * mi: Add Identify helper for ns-descs and primary-ctrl-caps
  * mi: Add firmware download and commit commands
  * mi: Add identify helper for nsid-capable Controller List
  * mi: Add identify helpers for namespace lists
  * mi: Add identify helpers for namespaces
  * mi: Allow Admin-message sized More Processing Required responses
  * mi: Distinguish MI status from NVMe (CDW3) status
  * mi: Fix C++ compiler errors
  * mi: Implement Format NVM command
  * mi: Implement Get & Set Features Admin commands
  * mi: Implement NS attach command and helpers
  * mi: Implement Namespace Management command and create/delete helpers
  * mi: Implement Sanitize command
  * mi: Init ctrl_id within xfer
  * mi: Introduce a helper for response status, unify values with ioctls
  * mi: Set log page offset for nvme_get_log_telemetry_host
  * mi: add nvme_mi_status_to_string()
  * mi: fix a memory leak in nvme_mi_open_mctp()
  * mi: fix get_log_page chunked offset check
  * nvme-tree: avoid segfault if auth keys are unavailable
  * python: Use nvmf_get_discovery_wargs()
  * tree: rename controller 'dhchap_key' to 'dhchap_ctrl_key'
  * types: Move enum nvme_data_tfr to types
  * util: Add LINE_MAX define
  * util: Add get feature length 2 API to support direction parameter
  * util: Add simple UUID type
  * util: Do not expose fallthrough defines
- Make man page build conditiional. Install man page location has been
  fixed upstream.
- Mark the Python directory own by the libnvme3-python package
* Mon Oct 31 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Use fixed manpage build date (boo#1047218)
* Fri Aug 26 2022 Thorsten Kukuk <kukuk@suse.com>
- Fix installation of manual pages to make them accessible
* Tue Aug  2 2022 Dirk Müller <dmueller@suse.com>
- Update to version 1.1:
  * Regenerate all documentation
  * json: fixup dhchap_ctrl_key definitions
  * fabrics: Fix build_options() return values
  * fabrics: sanitize dump-config output
  * Fix poll.h includes
  * build: Drop -nostdinc for LibreSSL header checks
  * ioctl: Honor rae in nvme_get_nsid_log
  * build: Add support to build against LibreSSL
  * rpmbuild: Enable 'make rpm' to build rpm pkgs #408
  * mi: unify MI Get Log Page function with ioctl API
  * python: add missing ctrl attrs to Python bindings
  * mi-mctp: Add timeout support to MCTP transport
  * mi: Add maximum More Processing Required limit API
  * mi: Add endpoint get/set timeout API
* Thu Jul 14 2022 daniel.wagner@suse.com
- Update to version v1.1-rc0:
  * update/cleanup of documentation
  * various build fixes
  * various fixes reported by coverity
  * 64-bit Reference Tags and TP-4068 changes
  * libnvme-mi: Introduce NVMe Managament Interface library
* Fri Apr  8 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to version 1.0:
  * tree: Remove default port setting for TCP and RDMA ports
  * tree: add 'f_args' argument to pass user data to the filter function
  * tree: remove 'ctrl_get_ana_state()'
  * tree: add namespace path iterators
  * tree: filter out namespaces
  * tree: update nvme_scan_filter_t usage
* Fri Apr  1 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to version 1.0-rc8:
  * types: Add support for get log - MI Command Supported
  * types: Add new Identify constant
  * types: Update persistent event entry struct added new fields
  * types: Add Host Initiated Data Gen Number to telemetry log struct
  * tree: always allocate config file in nvme_read_config()
  * tree: rework nvme_scan_subsystem()
  * tree: make subsystem name mandatory in nvme_scan_ctrl()
  * tree: move nvme_init_subsystem() into nvme_lookup_subsystem()
  * tree: do not return error when filtering out subsystems
  * tree: add debugging messages during scanning
  * tree: Handle NULL subsysname in nvme_scan_ctrl()
  * tree: Fix subsystem initialization in nvme_scan_ctrl()
  * tree: Fix leaking 'name' in nvme_subsystem_lookup_namespace()
  * tree: Avoid dereferencing nvme_subsystem_t before its check for NULL
  * tree: Clarify NULL return values from nvme_get_attr()
  * fabrics: Invoke nvmf_dim() with provided tas argument
  * fabrics: add 'nvmf_update_config()'
  * fabrics: Avoid out of bounds string chomping
  * fabrics: Free old traddr in nvmf_add_ctrl
  * fabrics: update log level for write failures
  * fabrics: Streamlining documentation
  * fabrics: Fix leaking ctrl in nvmf_connect_disc_entry()
  * fabrics: Add missing break in a switch
  * ioctl: Remove attribute packed and alignedof for args structs
  * ioctl: Align arguments indentation with braces
  * json: fix endless loop scanning for controllers
  * Remove nvme_init_id_ns
  * Add lbstm support for create-ns
  * documentation updates
* Fri Mar 18 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to version 1.0-rc7:
  * linux: fixup log page offset in nvme_get_log_page()
  * tree: Add support for default trsvcid for all controllers (bsc#1195858)
  * tree: fixup coredump during nvme discover
* Fri Mar 11 2022 Daniel Wagnrer <daniel.wagner@suse.com>
- Update to version 1.0-rc6:
  * tree: add nvme_ctrl_get_ana_state() (bsc#1195938)
  * tree: link paths to namespaces in nvme_subsystem_scan_namespace() (bsc#1195938)
  * ioctl.h: ns list bug fix (wrong cns value)
  * types.h: Key Value Command Set Identifier added (NVME_CSI_KV)
  * types: fix status code type bug (wrong masking)
* Tue Mar  8 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update License information. The library is released under
  LGPL-2.1-or-later and not LGPL-2.1-only.
* Thu Mar  3 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to version 1.0-rc5:
  * ioctl: Set lsp to action in nvme_get_log_persistent_event (bsc#1196121)
  * tree: Ignore traddr case in nvme_lookup_ctrl() (bsc#1194025)
  * fabrics: Do not swap bytes for system uuid (bsc#1196565)
  * documentation updates
* Tue Feb 22 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to version 1.0-rc4:
  * fabrics: add default port number for NVMe/TCP I/O controllers
  * linux: Update size when telemetry controller initiated data is unavailable
  * add cdw13 for set_feature_args structure
  * Add support for TP8010
  * Documentation cleanups
* Fri Feb 11 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to version v1.0-rc3:
  * Properly create manuals/documentation
  * Fix memleaks in __nvme_free_ns() and nvme_scan_subsystem()
  * nvme: get log domain id included in Log Specific Identifier
  * nvme: Add nulbaf(Number of Unique Capability LBA Formats) field on nvmd_id_ns
  * ioctl: Add identify ioctl for CNS 09h, 0Ah
  * nvme: Add Enhanced Controller Meta Data(FID: 0x7D)
  * nvme: Add Supported Capacity Configuration List log page(LID: 0x11)
  * tree: do not set dhchap_key to 'none'
  * tree: restart controller lookup
  * tree: fixup memory leak in nvme_scan_ctrl()
  * Rename nvme_path_get_subsystem()
  * Remove nvme_reset_topology()
- Use precompiled documentation instead regenerating it
* Tue Feb  1 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to version 1.0~2:
  * Add fabrics config option 'tls'
  * Logging infrastructure reworked (API break)
  * Changed argument structs layout (API break)
  * Changed scan API (API break)
  * Fixed ctrl_loss_tmo handling concerning values of '-1'
  * Various build fixes
* Wed Jan 19 2022 Daniel Wagner <daniel.wagner@suse.com>
- Remove Provide for python package.
- Remove explicit tar file name for setup step.
* Tue Jan 18 2022 Daniel Wagner <daniel.wagner@suse.com>
- Use osc_scm to manage upstream input source.
* Tue Jan 18 2022 Daniel Wagner <daniel.wagner@suse.com>
- Fix Source URL
* Fri Jan 14 2022 Daniel Wagner <daniel.wagner@suse.com>
- Initial package creation for libnvme
